==> jc-1.4.0.tar.gz: soot/jimple/parser/node/AVoidType.h <==
// public final class soot.jimple.parser.node.AVoidType

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c9c8a40767dd3c0e soot_jimple_parser_node_AVoidType
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class 7d83a0229405aa04 soot_jimple_parser_node_PType

// header file dependencies
// @dep_header soot_jimple_parser_node_PType

#include "soot/jimple/parser/node/PType.h"

#ifndef _JC_soot_jimple_parser_node_AVoidType_H_
#define _JC_soot_jimple_parser_node_AVoidType_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TVoid$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_AVoidType$sub_refs	_jc_soot_jimple_parser_node_AVoidType$sub_refs;
typedef struct _jc_soot_jimple_parser_node_AVoidType$sub_nonrefs	_jc_soot_jimple_parser_node_AVoidType$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_AVoidType$refs	_jc_soot_jimple_parser_node_AVoidType$refs;
typedef struct _jc_soot_jimple_parser_node_AVoidType$nonrefs	_jc_soot_jimple_parser_node_AVoidType$nonrefs;
typedef struct _jc_soot_jimple_parser_node_AVoidType$object	_jc_soot_jimple_parser_node_AVoidType$object;

typedef const struct _jc_soot_jimple_parser_node_AVoidType$vmethods	_jc_soot_jimple_parser_node_AVoidType$vmethods;
typedef const struct _jc_soot_jimple_parser_node_AVoidType$vtable	_jc_soot_jimple_parser_node_AVoidType$vtable;
typedef const struct _jc_soot_jimple_parser_node_AVoidType$vtype	_jc_soot_jimple_parser_node_AVoidType$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_AVoidType$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_AVoidType$object *);
extern void _jc_soot_jimple_parser_node_AVoidType$method$_init$2852e1d56c326910(_jc_env *, struct _jc_soot_jimple_parser_node_AVoidType$object *, struct _jc_soot_jimple_parser_node_TVoid$object *);

// Virtual methods
extern void _jc_soot_jimple_parser_node_AVoidType$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_AVoidType$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_AVoidType$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_AVoidType$object *);
extern struct _jc_soot_jimple_parser_node_TVoid$object *_jc_soot_jimple_parser_node_AVoidType$method$getVoid$1b2c0cbc21bbc7c6(_jc_env *, struct _jc_soot_jimple_parser_node_AVoidType$object *);
extern void _jc_soot_jimple_parser_node_AVoidType$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_AVoidType$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_AVoidType$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_AVoidType$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_AVoidType$method$setVoid$7175fb16f5723c0b(_jc_env *, struct _jc_soot_jimple_parser_node_AVoidType$object *, struct _jc_soot_jimple_parser_node_TVoid$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_AVoidType$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_AVoidType$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_AVoidType$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_AVoidType$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_AVoidType$method_info$getVoid$1b2c0cbc21bbc7c6;
extern _jc_method _jc_soot_jimple_parser_node_AVoidType$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_AVoidType$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_AVoidType$method_info$setVoid$7175fb16f5723c0b;
extern _jc_method _jc_soot_jimple_parser_node_AVoidType$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_AVoidType$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_AVoidType$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_AVoidType$object *);
	struct _jc_soot_jimple_parser_node_TVoid$object	*(*getVoid$1b2c0cbc21bbc7c6)(_jc_env *, struct _jc_soot_jimple_parser_node_AVoidType$object *);
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_AVoidType$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_AVoidType$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*setVoid$7175fb16f5723c0b)(_jc_env *, struct _jc_soot_jimple_parser_node_AVoidType$object *, struct _jc_soot_jimple_parser_node_TVoid$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_AVoidType$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_AVoidType$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PType$vmethods	soot_jimple_parser_node_PType;
	_jc_soot_jimple_parser_node_AVoidType$vmethods	soot_jimple_parser_node_AVoidType;
};

// Vtype
struct _jc_soot_jimple_parser_node_AVoidType$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_AVoidType$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AVoidType$sub_refs {
	struct _jc_soot_jimple_parser_node_TVoid$object	*__5fvoid__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_AVoidType$refs {
    _jc_soot_jimple_parser_node_AVoidType$sub_refs	soot_jimple_parser_node_AVoidType;
    _jc_soot_jimple_parser_node_PType$sub_refs	soot_jimple_parser_node_PType;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AVoidType$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_AVoidType$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PType$sub_nonrefs	soot_jimple_parser_node_PType;
    _jc_soot_jimple_parser_node_AVoidType$sub_nonrefs	soot_jimple_parser_node_AVoidType;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_AVoidType$object {
	_jc_soot_jimple_parser_node_AVoidType$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_AVoidType$vtype	*vtype;
	_jc_soot_jimple_parser_node_AVoidType$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_AVoidType$vtype _jc_soot_jimple_parser_node_AVoidType$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_AVoidType, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_AVoidType$class_object;

#endif	/* _JC_soot_jimple_parser_node_AVoidType_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/AVoidType.h <==
// public final class soot.jimple.parser.node.AVoidType

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class c9c8a40767dd3c0e soot_jimple_parser_node_AVoidType
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class 7d83a0229405aa04 soot_jimple_parser_node_PType

// header file dependencies
// @dep_header soot_jimple_parser_node_PType

#include "soot/jimple/parser/node/PType.h"

#ifndef _JC_soot_jimple_parser_node_AVoidType_H_
#define _JC_soot_jimple_parser_node_AVoidType_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TVoid$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_AVoidType$sub_refs	_jc_soot_jimple_parser_node_AVoidType$sub_refs;
typedef struct _jc_soot_jimple_parser_node_AVoidType$sub_nonrefs	_jc_soot_jimple_parser_node_AVoidType$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_AVoidType$refs	_jc_soot_jimple_parser_node_AVoidType$refs;
typedef struct _jc_soot_jimple_parser_node_AVoidType$nonrefs	_jc_soot_jimple_parser_node_AVoidType$nonrefs;
typedef struct _jc_soot_jimple_parser_node_AVoidType$object	_jc_soot_jimple_parser_node_AVoidType$object;

typedef const struct _jc_soot_jimple_parser_node_AVoidType$vmethods	_jc_soot_jimple_parser_node_AVoidType$vmethods;
typedef const struct _jc_soot_jimple_parser_node_AVoidType$vtable	_jc_soot_jimple_parser_node_AVoidType$vtable;
typedef const struct _jc_soot_jimple_parser_node_AVoidType$vtype	_jc_soot_jimple_parser_node_AVoidType$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_AVoidType$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_AVoidType$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AVoidType$method$_init$2852e1d56c326910(_jc_env *, struct _jc_soot_jimple_parser_node_AVoidType$object *, struct _jc_soot_jimple_parser_node_TVoid$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_node_AVoidType$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_AVoidType$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_AVoidType$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_AVoidType$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_parser_node_TVoid$object *_jc_soot_jimple_parser_node_AVoidType$method$getVoid$1b2c0cbc21bbc7c6(_jc_env *, struct _jc_soot_jimple_parser_node_AVoidType$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AVoidType$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_AVoidType$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AVoidType$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_AVoidType$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AVoidType$method$setVoid$7175fb16f5723c0b(_jc_env *, struct _jc_soot_jimple_parser_node_AVoidType$object *, struct _jc_soot_jimple_parser_node_TVoid$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_AVoidType$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_AVoidType$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_AVoidType$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_AVoidType$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_AVoidType$method_info$getVoid$1b2c0cbc21bbc7c6;
extern _jc_method _jc_soot_jimple_parser_node_AVoidType$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_AVoidType$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_AVoidType$method_info$setVoid$7175fb16f5723c0b;
extern _jc_method _jc_soot_jimple_parser_node_AVoidType$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_AVoidType$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_AVoidType$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_AVoidType$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_parser_node_TVoid$object	*(*getVoid$1b2c0cbc21bbc7c6)(_jc_env *, struct _jc_soot_jimple_parser_node_AVoidType$object *) _JC_JCNI_ATTR;
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_AVoidType$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_AVoidType$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*setVoid$7175fb16f5723c0b)(_jc_env *, struct _jc_soot_jimple_parser_node_AVoidType$object *, struct _jc_soot_jimple_parser_node_TVoid$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_AVoidType$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_AVoidType$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PType$vmethods	soot_jimple_parser_node_PType;
	_jc_soot_jimple_parser_node_AVoidType$vmethods	soot_jimple_parser_node_AVoidType;
};

// Vtype
struct _jc_soot_jimple_parser_node_AVoidType$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_AVoidType$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AVoidType$sub_refs {
	struct _jc_soot_jimple_parser_node_TVoid$object	*__5fvoid__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_AVoidType$refs {
    _jc_soot_jimple_parser_node_AVoidType$sub_refs	soot_jimple_parser_node_AVoidType;
    _jc_soot_jimple_parser_node_PType$sub_refs	soot_jimple_parser_node_PType;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AVoidType$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_AVoidType$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PType$sub_nonrefs	soot_jimple_parser_node_PType;
    _jc_soot_jimple_parser_node_AVoidType$sub_nonrefs	soot_jimple_parser_node_AVoidType;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_AVoidType$object {
	_jc_soot_jimple_parser_node_AVoidType$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_AVoidType$vtype	*vtype;
	_jc_soot_jimple_parser_node_AVoidType$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_AVoidType$vtype _jc_soot_jimple_parser_node_AVoidType$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_AVoidType, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_AVoidType$class_object;

#endif	/* _JC_soot_jimple_parser_node_AVoidType_H_ */
